@@ -6,10 +6,7 @@ use warnings;
 use base 'Log::Mini::LoggerBase';
 
 sub _print {
-    my $self = shift;
-    my ($message) = @_;
-
-    print STDERR $message;
+    print STDERR $_[1];
 }
 
 1;
